@@ -1,72 +1,49 @@
-import socket
-from unittest.mock import patch, Mock
-
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
-
+from unittest.mock import Mock, patch
 
 from django.core.cache import InvalidCacheBackendError
-from nose.tools import (
-    eq_,
-    raises,
-)
+from nose.tools import eq_, raises
+
+from django_elastipymemcache.client import ConfigurationEndpointClient
 
 
 @raises(InvalidCacheBackendError)
 def test_multiple_servers():
-    from django_elastipymemcache.memcached import (
-        ElastiPyMemCache,
-    )
-    ElastiPyMemCache('h1:0,h2:0', {})
+    from django_elastipymemcache.backend import ElastiPymemcache
+    ElastiPymemcache('h1:0,h2:0', {})
 
 
 @raises(InvalidCacheBackendError)
 def test_wrong_server_format():
-    from django_elastipymemcache.memcached import (
-        ElastiPyMemCache,
-    )
-    ElastiPyMemCache('h', {})
+    from django_elastipymemcache.backend import ElastiPymemcache
+    ElastiPymemcache('h', {})
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
 def test_split_servers(get_cluster_info):
-    from django_elastipymemcache.memcached import (
-        ElastiPyMemCache,
-        deserialize_pickle,
-        serialize_pickle,
-    )
-    backend = ElastiPyMemCache('h:0', {})
+    from django_elastipymemcache.backend import ElastiPymemcache
+    backend = ElastiPymemcache('h:0', {})
     servers = [('h1', 0), ('h2', 0)]
     get_cluster_info.return_value = {
         'nodes': servers
     }
     backend._lib.Client = Mock()
     assert backend._cache
-    get_cluster_info.assert_called_once_with(
-            'h', '0', False, socket._GLOBAL_DEFAULT_TIMEOUT)
+    get_cluster_info.assert_called()
     backend._lib.Client.assert_called_once_with(
         servers,
-        deserializer=deserialize_pickle,
         ignore_exc=True,
-        serializer=serialize_pickle
     )
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
 def test_node_info_cache(get_cluster_info):
-    from django_elastipymemcache.memcached import (
-        ElastiPyMemCache,
-        deserialize_pickle,
-        serialize_pickle,
-    )
-    servers = [('h1', 0), ('h2', 0)]
+    from django_elastipymemcache.backend import ElastiPymemcache
+    servers = ['h1:0', 'h2:0']
     get_cluster_info.return_value = {
         'nodes': servers
     }
 
-    backend = ElastiPyMemCache('h:0', {})
+    backend = ElastiPymemcache('h:0', {})
     backend._lib.Client = Mock()
     backend.set('key1', 'val')
     backend.get('key1')
@@ -74,34 +51,31 @@ def test_node_info_cache(get_cluster_info):
     backend.get('key2')
     backend._lib.Client.assert_called_once_with(
         servers,
-        deserializer=deserialize_pickle,
         ignore_exc=True,
-        serializer=serialize_pickle
     )
     eq_(backend._cache.get.call_count, 2)
     eq_(backend._cache.set.call_count, 2)
 
-    get_cluster_info.assert_called_once_with(
-            'h', '0', False, socket._GLOBAL_DEFAULT_TIMEOUT)
+    get_cluster_info.assert_called_once()
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
 def test_failed_to_connect_servers(get_cluster_info):
-    from django_elastipymemcache.memcached import ElastiPyMemCache
-    backend = ElastiPyMemCache('h:0', {})
+    from django_elastipymemcache.backend import ElastiPymemcache
+    backend = ElastiPymemcache('h:0', {})
     get_cluster_info.side_effect = OSError()
     eq_(backend.get_cluster_nodes(), [])
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
 def test_invalidate_cache(get_cluster_info):
-    from django_elastipymemcache.memcached import ElastiPyMemCache
-    servers = [('h1', 0), ('h2', 0)]
+    from django_elastipymemcache.backend import ElastiPymemcache
+    servers = ['h1:0', 'h2:0']
     get_cluster_info.return_value = {
         'nodes': servers
     }
 
-    backend = ElastiPyMemCache('h:0', {})
+    backend = ElastiPymemcache('h:0', {})
     backend._lib.Client = Mock()
     assert backend._cache
     backend._cache.get = Mock()
@@ -121,16 +95,44 @@ def test_invalidate_cache(get_cluster_info):
     eq_(get_cluster_info.call_count, 3)
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
-def test_client_get_many(get_cluster_info):
-    from django_elastipymemcache.memcached import ElastiPyMemCache
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
+def test_client_add(get_cluster_info):
+    from django_elastipymemcache.backend import ElastiPymemcache
 
-    servers = [('h1', 0), ('h2', 0)]
+    servers = ['h1:0', 'h2:0']
     get_cluster_info.return_value = {
         'nodes': servers
     }
 
-    backend = ElastiPyMemCache('h:0', {})
+    backend = ElastiPymemcache('h:0', {})
+    ret = backend.add('key1', 'value1')
+    eq_(ret, False)
+
+
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
+def test_client_delete(get_cluster_info):
+    from django_elastipymemcache.backend import ElastiPymemcache
+
+    servers = ['h1:0', 'h2:0']
+    get_cluster_info.return_value = {
+        'nodes': servers
+    }
+
+    backend = ElastiPymemcache('h:0', {})
+    ret = backend.delete('key1')
+    eq_(ret, None)
+
+
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
+def test_client_get_many(get_cluster_info):
+    from django_elastipymemcache.backend import ElastiPymemcache
+
+    servers = ['h1:0', 'h2:0']
+    get_cluster_info.return_value = {
+        'nodes': servers
+    }
+
+    backend = ElastiPymemcache('h:0', {})
     ret = backend.get_many(['key1'])
     eq_(ret, {})
 
@@ -179,55 +181,57 @@ def test_client_get_many(get_cluster_info):
         )
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
 def test_client_set_many(get_cluster_info):
-    from django_elastipymemcache.memcached import ElastiPyMemCache
+    from django_elastipymemcache.backend import ElastiPymemcache
 
-    servers = [('h1', 0), ('h2', 0)]
+    servers = ['h1:0', 'h2:0']
     get_cluster_info.return_value = {
         'nodes': servers
     }
 
-    backend = ElastiPyMemCache('h:0', {})
+    backend = ElastiPymemcache('h:0', {})
     ret = backend.set_many({'key1': 'value1', 'key2': 'value2'})
     eq_(ret, ['key1', 'key2'])
 
 
-@patch('django_elastipymemcache.memcached.get_cluster_info')
-def test_client_delete(get_cluster_info):
-    from django_elastipymemcache.memcached import ElastiPyMemCache
-
-    servers = [('h1', 0), ('h2', 0)]
-    get_cluster_info.return_value = {
-        'nodes': servers
-    }
-
-    backend = ElastiPyMemCache('h:0', {})
-    ret = backend.delete('key1')
-    eq_(ret, None)
-
-
-@patch('django_elastipymemcache.memcached.get_cluster_info')
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
 def test_client_delete_many(get_cluster_info):
-    from django_elastipymemcache.memcached import ElastiPyMemCache
+    from django_elastipymemcache.backend import ElastiPymemcache
 
-    servers = [('h1', 0), ('h2', 0)]
+    servers = ['h1:0', 'h2:0']
     get_cluster_info.return_value = {
         'nodes': servers
     }
 
-    backend = ElastiPyMemCache('h:0', {})
+    backend = ElastiPymemcache('h:0', {})
     ret = backend.delete_many(['key1', 'key2'])
     eq_(ret, None)
 
 
-def test_serialize_pickle():
-    from django_elastipymemcache.memcached import serialize_pickle
-    eq_(serialize_pickle('key', 'str'), ('str', 1))
-    eq_(serialize_pickle('key', 0), (pickle.dumps(0), 2))
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
+def test_client_incr(get_cluster_info):
+    from django_elastipymemcache.backend import ElastiPymemcache
+
+    servers = ['h1:0', 'h2:0']
+    get_cluster_info.return_value = {
+        'nodes': servers
+    }
+
+    backend = ElastiPymemcache('h:0', {})
+    ret = backend.incr('key1', 1)
+    eq_(ret, False)
 
 
-def test_deserialize_pickle():
-    from django_elastipymemcache.memcached import deserialize_pickle
-    eq_(deserialize_pickle('key', 'str', 1), 'str')
-    eq_(deserialize_pickle('key', pickle.dumps(0), 2), 0)
+@patch.object(ConfigurationEndpointClient, 'get_cluster_info')
+def test_client_decr(get_cluster_info):
+    from django_elastipymemcache.backend import ElastiPymemcache
+
+    servers = ['h1:0', 'h2:0']
+    get_cluster_info.return_value = {
+        'nodes': servers
+    }
+
+    backend = ElastiPymemcache('h:0', {})
+    ret = backend.decr('key1', 1)
+    eq_(ret, False)
